#
# spec file for package cloudflared
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cloudflared
Version:        2025.6.0
Release:        1.1
Summary:        Cloudflare Tunnel client
License:        Apache-2.0
Group:          Productivity/Networking/System
URL:            https://github.com/cloudflare/cloudflared
Source0:        https://github.com/cloudflare/cloudflared/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
# PATCH-FIX-OPENSUSE 001-skip-test.patch hillwood@opensuse.org
Patch0:         001-skip-test.patch
# PATCH-FIX-OPENSUSE 002-use-pie.patch hillwood@opensuse.org
Patch1:         002-use-pie.patch
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.24
AutoReqProv:    Off
%{go_provides}

%description
Contains the command-line client for Cloudflare Tunnel, a tunneling daemon that
proxies traffic from the Cloudflare network to your origins. This daemon sits
between Cloudflare network and your origin (e.g. a webserver). Cloudflare
attracts client requests and sends them to you via this daemon, without
requiring you to poke holes on your firewall --- your origin can remain as
closed as possible. Extensive documentation can be found in the Cloudflare
Tunnel section of the Cloudflare Docs. All usages related with proxying to your
origins are available under cloudflared tunnel help.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
rm -rf vendor
tar -zxf %{SOURCE1}
%make_build GOARCH=$(go env GOARCH)

%install
%make_install GOARCH=$(go env GOARCH)

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Jun 11 2025 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2025.6.0
  * Remove dynamic reloading of features for datagram v3
  * Add metric for unsupported RPC commands for datagram v3
  * Add dynamic loading of features to connections via ConnectionOptionsSnapshot
  * Use is_default_network instead of is_default to create vnet's
  * Update go to 1.24
* Sun May  4 2025 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2025.4.2
  * emit explicit errors for the service command on unsupported OSes
  * Fix some issues
- Drop update-vendor.patch and reproducible.patch
* Sat Dec 14 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.12.1
  * TUN-8748: Migrated datagram V3 flows to use migrated context
  * TUN-8737: update metrics server port selection
  * TUN-8731: Implement diag/system endpoint
  * TUN-8728: implement diag/tunnel endpoint
  * TUN-8730: implement diag/configuration
  * TUN-8735: add managed/local log collection
  * TUN-8733: add log collection for docker
  * TUN-8734: add log collection for kubernetes
  * TUN-8640: Refactor ICMPRouter to support new ICMPResponders
  * TUN-8729: implement network collection for diagnostic procedure
  * TUN-8727: implement metrics, runtime, system, and tunnelstate in diagnostic
    http client
  * TUN-8726: implement compression routine to be used in diagnostic procedure
  * TUN-8732: implement port selection algorithm
  * TUN-8762: fix argument order when invoking tracert and modify network info
    output parsing
  * TUN-8769: fix k8s log collector arguments
  * TUN-8727: extend client to include function to get cli configuration
    and tunnel configuration
  * TUN-8725: implement diagnostic procedure
  * TUN-8767: include raw output from network collector in diagnostic zip file
  * TUN-8770: add cli configuration and tunnel configuration to diagnostic zipfile
  * TUN-8768: add job report to diagnostic zipfile
  * TUN-8775: Make sure the session Close can only be called once
  * TUN-8781: Add Trixie, drop Buster. Default to Bookworm
  * TUN-8640: Add ICMP support for datagram V3
  * TUN-8789: make python package installation consistent
  * TUN-8795: update createrepo to createrepo_c to fix the release_pkgs.py
    script
- Add update-vendor.patch, fix CVE-2024-45337 and boo#1234582
* Mon Nov 25 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.11.1
  * Add cloudflared tunnel health command
  * PPIP-2310: Update quick tunnel disclaimer
  * TUN-8621: Prevent QUIC connection from closing before grace period
    after unregistering
  * TUN-8484: Print response when QuickTunnel can't be unmarshalled
  * TUN-8592: Use metadata from the edge to determine if request body is
    empty for QUIC transport
  * TUN-8621: Fix cloudflared version in change notes to account for
    release date
  * TUN-8638: Add datagram v3 serializers and deserializers
  * TUN-8685: Bump coredns dependency
  * TUN-8688: Correct UDP bind for IPv6 edge connectivity on macOS
  * TUN-8694: Fix github release script
  * TUN-8694: Rework release script
  * TUN-8661: Refactor connection methods to support future different
    datagram muxing methods
  * TUN-8692: remove dashes from session id
  * TUN-8708: Bump python min version to 3.10
  * TUN-8667: Add datagram v3 session manager
  * TUN-8553: Bump go to 1.22.5 and go-boring 1.22.5-1
  * TUN-8700: Add datagram v3 muxer
  * TUN-8646: Allow experimental feature support for datagram v3
  * TUN-8641: Expose methods to simplify V3 Datagram parsing on the edge
  * VULN-66059: remove ssh server tests
  * TUN-8709: Add session migration for datagram v3
  * TUN-8701: Add metrics and adjust logs for datagram v3
  * add: new go-fuzz targets
  * TUN-8701: Simplify flow registration logs for datagram v3
* Fri Sep 13 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.9.1
  * TUN-8546: Fix final artifacts paths
  * TUN-8583: change final directory of artifacts
  * TUN-8585: Avoid creating GH client when dry-run is true
  * TUN-8591 login command without extra text
  * TUN-8592: Use metadata from the edge to determine if request body is
    empty for QUIC transport
  * TUN-8484: Print response when QuickTunnel can't be unmarshalled
  * TUN-8621: Prevent QUIC connection from closing before grace period after
    unregistering
  * PPIP-2310: Update quick tunnel disclaimer
* Mon Aug  5 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.7.3
  * TUN-8546: Fix final artifacts paths
* Tue Jul 30 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.7.1
  * Add user-agent for quick-tunnel requests
  * Add default noop logger for capnprpc
  * cloudflared uses new PQ curve ID
  * use -p flag to create intermediate directories
* Wed Jul 17 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to not include the build date (boo#1047218)
* Mon Jul  8 2024 Andreas Schwab <schwab@suse.de>
- Define GOARCH
- Remove 003-support-ppc64le.patch.
* Thu Jul  4 2024 Hillwood Yang <hillwood@opensuse.org>
- Add 003-support-ppc64le.patch
* Mon Jun 17 2024 Hillwood Yang <hillwood@opensuse.org>
- Initial package for version 2024.6.0
- Add 001-skip-test.patch and 002-use-pie.patch
